# SAML authentication with Latvija.lv

## Intro

This module provides a simple method to authenticate users with Latvija.lv and pass
the user data to Drupal for processing (for example, to create or authenticate users).

NOTE: The authentication with Latvija.lv is only possible for public sector institutions.

## Dependencies

The module has the following dependencies:

- `drupal/core: ^9.4 || ^10`
- `onelogin/php-saml: ^4.2`
- `defuse/php-encryption: ^2.4`

## Features

The authentication with Latvija.lv is performed via the Saml protocol, where the service
provider (SP) is your application, and Latvija.lv acts as an identity provider (IdP).

There are many Saml-based Drupal modules, but this module has the following features:

1. Simple configuration.
2. Customizable action after successful authentication with Latvija.lv. By default,
   no action is performed when the user authenticates with Latvija.lv. The developer
   has to create a Drupal service, which performs a certain action when the user
   authenticates with Latvija.lv and when the user logs out of the system.
3. Detailed logging capabilities for debugging purposes.

## Configuration

In order to configure the module, you need to prepare the following data for
your SP application.

### The encryption key

Generate an encryption key, which is used to encrypt the user data.

```
vendor/bin/generate-defuse-key
```

### The SP certificate

Generate a certificate request for the environment where the application is going to be
hosted on.

```
openssl req -newkey rsa:2048 -keyout myapp.lv.private.key -out myapp.lv.csr -nodes
```

After sending the certificate request to Latvija.lv, you will receive an SP certificate from the IdP.

### The IdP certificate

The certificate of the IdP is included in the Saml metadata file.

### Miscellaneous

You should receive the following information from Latvija.lv:

1. The service provider identification (SP realm) for your application.
2. The IdP Saml metadata XML URL. It will contain the following required information:
   3. The IdP entity ID (see the `EntityDescriptor#entityID` element attribute);
   4. The IdP certificate (see the `EntityDescriptor > Signature > KeyInfo > X509Data > X509Certificate` element value).
2. The IdP end-point URL for the sign-on operation (SP SSO URL).
3. The IdP end-point URL for the sign-out operation (SP SLO URL).

The information you should send to Latvija.lv:

1. The URL of the reply end-point (`/auth/acs`).
2. The certificate request.

### Authentication handling

By default, the module doesn't handle the authenticated user data received from Latvija.lv, as each
website has a specific use case, e.g., create or authenticate a Drupal user based on the national ID
number as an account name, or create a temporary session.

In order to create a custom authentication service, make sure that it conforms to
`\Drupal\latvia_auth_saml\AuthenticationServiceInterface`.

After creating a service, make sure you define the authentication service name in `settings.php`:

```
$settings['latvia_auth_saml.authentication_service_name'] = 'mymodule.authentication_service';
```

### Drupal settings

The following lines need to be added to `settings.php`:

```php
// The SP settings.
$settings['latvia_auth_saml.sp_entity_id'] = '[Enter the SP realm]';
$settings['latvia_auth_saml.sp_cert_path'] = '[Enter the absolute path to the SP certificate]';
$settings['latvia_auth_saml.sp_private_key_path'] = '[Enter the absolute path to the private key of the SP certificate]';

// The IdP settings.
$settings['latvia_auth_saml.idp_entity_id'] = '[Enter the IdP entity ID]';
$settings['latvia_auth_saml.idp_sso_path'] = '[Enter the sign-on end-point URL]';
$settings['latvia_auth_saml.idp_slo_path'] = 'Enter the sign-out end-point URL';
$settings['latvia_auth_saml.ipd_cert_path'] = '[Enter the absolute path to the IdP certificate]';

// The encryption settings.
$settings['latvia_auth_saml.encryption.key'] = '[Enter the encryption key.]';

// The Drupal service responsible for the authentication handling.
$settings['latvia_auth_saml.authentication_service_name'] = 'mymodule.authentication_service';

// The debugging settings. Set to TRUE only in testing environments.
$settings['latvia_auth_saml.debug'] = FALSE;
```

### Authentication

To initiate the authentication via Latvija.lv, point the user to `/auth/sso`.

To log the user out from Latvija.lv, point the user to `/auth/slo`.

### Debugging

If debugging is enabled in `settings.php`, noteworthy events from the Saml message exchange will
be logged into Drupal logging system.

If a thrown exception implements the `PassThroughExceptionMessageInterface` interface, the message
of the exception will not only be logged, but also displayed to the user.
