<?php

namespace Drupal\latvia_auth_saml;

/**
 * The authentication service interface.
 */
interface AuthenticationServiceInterface {

  /**
   * Defines the authentication request ID variable name.
   */
  const SESSION_AUTH_REQUEST_ID = 'authn_request_id';

  /**
   * Defines the logout request ID variable name.
   */
  const SESSION_LOGOUT_REQUEST_ID = 'logout_request_id';

  /**
   * Authenticates the user in the system.
   *
   * @param array $attributes
   *   The Saml assertion attributes.
   * @param string $return_to
   *   Relay state URL.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse|false
   *   Redirect response which indicates that the user has been logged in or
   *   FALSE if login failed.
   *
   * @see self::processLoginRequest()
   */
  public function processLogin(array $attributes, $return_to = NULL);

  /**
   * Logs the user out of the system.
   *
   * @return void
   *   Nothing is returned by the method.
   */
  public function processLogout();

}
