<?php

namespace Drupal\latvia_auth_saml;

use Defuse\Crypto\Crypto;
use Defuse\Crypto\Key;
use Drupal\Core\Site\Settings;

/**
 * Encryption filter service provides methods for encryption and decryption.
 */
class EncryptionFilter implements FilterInterface {

  /**
   * Returns the encryption key instance.
   *
   * @return \Defuse\Crypto\Key
   *   The encryption key instance.
   */
  protected function getKey() {
    $key = Settings::get('latvia_auth_saml.encryption.key');

    return Key::loadFromAsciiSafeString($key);
  }

  /**
   * {@inheritdoc}
   */
  public function filter($string) {
    $key = $this->getKey();

    return Crypto::encrypt($string, $key);
  }

  /**
   * {@inheritdoc}
   */
  public function unfilter($string) {
    $key = $this->getKey();

    try {
      return Crypto::decrypt($string, $key);
    }
    catch (\Exception $e) {
      watchdog_exception('latvia_auth_saml', $e);
    }

    return FALSE;
  }

}
