<?php

namespace Drupal\latvia_auth_saml;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Site\Settings;
use Drupal\Core\Url;

/**
 * The Saml settings class.
 */
class SamlSettings implements SamlSettingsInterface {

  /**
   * {@inheritdoc}
   */
  public function get(array $settings = []) {
    /** @var \Drupal\Core\Site\Settings $site_settings */
    $site_settings = \Drupal::service('settings');

    $default_settings = [
      'strict' => TRUE,
      'debug' => (bool) $site_settings->get('latvia_auth_saml.debug', FALSE),
      'sp' => [
        'entityId' => $site_settings->get('latvia_auth_saml.sp_entity_id'),
        'assertionConsumerService' => [
          'url' => Url::fromRoute('latvia_auth_saml.acs', [], ['absolute' => TRUE])->toString(TRUE)->getGeneratedUrl(),
          'binding' => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST',
        ],
        'singleLogoutService' => [
          'url' => Url::fromRoute('latvia_auth_saml.sls', [], ['absolute' => TRUE])->toString(TRUE)->getGeneratedUrl(),
          'binding' => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
        ],
        'x509cert' => file_get_contents(Settings::get('latvia_auth_saml.sp_cert_path')),
        'privateKey' => file_get_contents($site_settings->get('latvia_auth_saml.sp_private_key_path')),
      ],
      'idp' => [
        'entityId' => $site_settings->get('latvia_auth_saml.idp_entity_id'),
        'singleSignOnService' => [
          'url' => $site_settings->get('latvia_auth_saml.idp_sso_path'),
          'binding' => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
        ],
        'singleLogoutService' => [
          'url' => $site_settings->get('latvia_auth_saml.idp_slo_path'),
          'binding' => 'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect',
        ],
        'x509cert' => file_get_contents(Settings::get('latvia_auth_saml.ipd_cert_path')),
      ],
      'security' => [
        'wantAssertionsSigned' => TRUE,
        'wantMessagesSigned' => TRUE,
        'wantAssertionsEncrypted' => TRUE,
      ],
    ];

    return NestedArray::mergeDeep($default_settings, $settings);
  }

}
